@@ -129,6 +129,7 @@ predict.divfor <- function(object, data = NULL, predict.all = FALSE,
 }
 
 # Author: Marvin N. Wright, Roman Hornung
+#' @export
 predict.divfor.forest <- function(object, data, predict.all = FALSE,
                                   num.trees = object$num.trees, 
                                   type = "response", se.method = "infjack",
@@ -383,7 +384,8 @@ predict.divfor.forest <- function(object, data, predict.all = FALSE,
                       case.weights, use.case.weights, class.weights, 
                       predict.all, keep.inbag, sample.fraction, alpha, minprop, holdout, 
                       prediction.type, num.random.splits, sparse.data, use.sparse.data,
-                      order.snps, oob.error, max.depth, inbag, use.inbag, nsplits, npairs=0, proptry, divfortype=1, promispairs=list(0,0), eim_mode=0) ## asdf
+                      order.snps, oob.error, max.depth, inbag, use.inbag, nsplits, npairs=0, proptry, divfortype=1, 
+					  promispairs=list(0,0), eim_mode=0, metricind=numeric(0)) ## asdf
 
   if (length(result) == 0) {
     stop("User interrupt or internal error.")
