@@ -208,77 +208,6 @@ void ForestSurvival::computePredictionErrorInternal() {
 }
 
 // #nocov start
-void ForestSurvival::writeOutputInternal() {
-  if (verbose_out) {
-    *verbose_out << "Tree type:                         " << "Survival" << std::endl;
-    *verbose_out << "Status variable name:              " << data->getVariableNames()[status_varID] << std::endl;
-    *verbose_out << "Status variable ID:                " << status_varID << std::endl;
-  }
-}
-
-void ForestSurvival::writeConfusionFile() {
-
-  // Open confusion file for writing
-  std::string filename = output_prefix + ".confusion";
-  std::ofstream outfile;
-  outfile.open(filename, std::ios::out);
-  if (!outfile.good()) {
-    throw std::runtime_error("Could not write to confusion file: " + filename + ".");
-  }
-
-  // Write confusion to file
-  outfile << "Overall OOB prediction error (1 - C): " << overall_prediction_error << std::endl;
-
-  outfile.close();
-  if (verbose_out)
-    *verbose_out << "Saved prediction error to file " << filename << "." << std::endl;
-
-}
-
-void ForestSurvival::writePredictionFile() {
-
-  // Open prediction file for writing
-  std::string filename = output_prefix + ".prediction";
-  std::ofstream outfile;
-  outfile.open(filename, std::ios::out);
-  if (!outfile.good()) {
-    throw std::runtime_error("Could not write to prediction file: " + filename + ".");
-  }
-
-  // Write
-  outfile << "Unique timepoints: " << std::endl;
-  for (auto& timepoint : unique_timepoints) {
-    outfile << timepoint << " ";
-  }
-  outfile << std::endl << std::endl;
-
-  outfile << "Cumulative hazard function, one row per sample: " << std::endl;
-  if (predict_all) {
-    for (size_t k = 0; k < num_trees; ++k) {
-      outfile << "Tree " << k << ":" << std::endl;
-      for (size_t i = 0; i < predictions.size(); ++i) {
-        for (size_t j = 0; j < predictions[i].size(); ++j) {
-          outfile << predictions[i][j][k] << " ";
-        }
-        outfile << std::endl;
-      }
-      outfile << std::endl;
-    }
-  } else {
-    for (size_t i = 0; i < predictions.size(); ++i) {
-      for (size_t j = 0; j < predictions[i].size(); ++j) {
-        for (size_t k = 0; k < predictions[i][j].size(); ++k) {
-          outfile << predictions[i][j][k] << " ";
-        }
-        outfile << std::endl;
-      }
-    }
-  }
-
-  if (verbose_out)
-    *verbose_out << "Saved predictions to file " << filename << "." << std::endl;
-}
-
 void ForestSurvival::saveToFileInternal(std::ofstream& outfile) {
 
   // Write num_variables
@@ -295,80 +224,6 @@ void ForestSurvival::saveToFileInternal(std::ofstream& outfile) {
   saveVector1D(unique_timepoints, outfile);
 }
 
-void ForestSurvival::loadFromFileInternal(std::ifstream& infile) {
-
-  // Read number of variables
-  size_t num_variables_saved;
-  infile.read((char*) &num_variables_saved, sizeof(num_variables_saved));
-
-  // Read treetype
-  TreeType treetype;
-  infile.read((char*) &treetype, sizeof(treetype));
-  if (treetype != TREE_SURVIVAL) {
-    throw std::runtime_error("Wrong treetype. Loaded file is not a survival forest.");
-  }
-
-  // Read status_varID
-  infile.read((char*) &status_varID, sizeof(status_varID));
-
-  // Read unique timepoints
-  unique_timepoints.clear();
-  readVector1D(unique_timepoints, infile);
-
-  for (size_t i = 0; i < num_trees; ++i) {
-
-    // Read data
-    std::vector<std::vector<size_t>> child_nodeIDs;
-    readVector2D(child_nodeIDs, infile);
-    std::vector<size_t> split_varIDs;
-    readVector1D(split_varIDs, infile);
-    std::vector<double> split_values;
-    readVector1D(split_values, infile);
-	
-	std::vector<size_t> split_types;
-    std::vector<std::vector<size_t>> split_multvarIDs;
-    std::vector<std::vector<std::vector<bool>>> split_directs;
-    std::vector<std::vector<std::vector<double>>> split_multvalues;
-
-    // Read chf
-    std::vector<size_t> terminal_nodes;
-    readVector1D(terminal_nodes, infile);
-    std::vector<std::vector<double>> chf_vector;
-    readVector2D(chf_vector, infile);
-
-    // Convert chf to vector with empty elements for non-terminal nodes
-    std::vector<std::vector<double>> chf;
-    chf.resize(child_nodeIDs[0].size(), std::vector<double>());
-//    for (size_t i = 0; i < child_nodeIDs.size(); ++i) {
-//      chf.push_back(std::vector<double>());
-//    }
-    for (size_t j = 0; j < terminal_nodes.size(); ++j) {
-      chf[terminal_nodes[j]] = chf_vector[j];
-    }
-
-    // If dependent variable not in test data, change variable IDs accordingly
-    if (num_variables_saved > num_variables) {
-      for (auto& varID : split_varIDs) {
-        if (varID >= dependent_varID) {
-          --varID;
-        }
-      }
-    }
-    if (num_variables_saved > num_variables + 1) {
-      for (auto& varID : split_varIDs) {
-        if (varID >= status_varID) {
-          --varID;
-        }
-      }
-    }
-
-    // Create tree
-    trees.push_back(
-        std::make_unique<TreeSurvival>(child_nodeIDs, split_varIDs, split_values, split_types, split_multvarIDs, split_directs, split_multvalues, chf, &unique_timepoints,
-            &response_timepointIDs));
-  }
-}
-
 const std::vector<double>& ForestSurvival::getTreePrediction(size_t tree_idx, size_t sample_idx) const {
   const auto& tree = dynamic_cast<const TreeSurvival&>(*trees[tree_idx]);
   return tree.getPrediction(sample_idx);
